@@ -1,9 +1,9 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "diff-ansi" "20251126.1134"
-  "Display diff's using alternative diffing tools."
+(define-package "diff-ansi" "20251216.227"
+  "Display diffs using alternative diffing tools."
   '((emacs "29.1"))
   :url "https://codeberg.org/ideasman42/emacs-diff-ansi"
-  :commit "5db2c410fc754a919b5b6811277646da5a26778c"
-  :revdesc "5db2c410fc75"
+  :commit "dd600ebdc632c8f525dcba392526e6e56fcbca61"
+  :revdesc "dd600ebdc632"
   :authors '(("Campbell Barton" . "ideasman42@gmail.com"))
   :maintainers '(("Campbell Barton" . "ideasman42@gmail.com")))
